@@ -33,14 +33,17 @@ class Mappings(BaseModel):
 
 
 class RelationValue(BaseModel):
-    sourceColumn: str
-    targetColumn: str
+    sourceColumn: Optional[str]
+    targetColumn: Optional[str]
+    sourceDimension: Optional[str]
+    targetDimension: Optional[str]
+    sql : Optional[str]
 
 
 class Relation(BaseModel):
     name: str
-    label: str
-    description: Any
+    label: Optional[str]
+    description: Optional[str]
     relationType: str
     joinType: str
     modelName: str
@@ -56,7 +59,7 @@ class DimensionValue(BaseModel):
 
 
 class ReportOption(BaseModel):
-    looker: dict
+    looker: Optional[dict]
 
 
 class Dimension(BaseModel):
@@ -70,7 +73,7 @@ class Dimension(BaseModel):
     pivot: Any
     suggestions: Any
     postOperations: Optional[List[str]]
-    fieldType: str
+    fieldType: Optional[str]
     reportOptions: Optional[ReportOption]
     hidden: Any
     drills: Any
@@ -122,5 +125,3 @@ class MetriqlModel(BaseModel):
     measures: List[Measure]
     materializes: List[Materialize]
     alwaysFilters: Any
-    recipeId: int
-    recipePath: str
